roulette library

Copyright 2021 do9core

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. Roulette package @author do9core

Classes

AnimationConfig
Configuration for roulette roll animation behavior.
CurveAnimationConfig
An AnimationConfig that uses a Curve to ease the rotation over a fixed duration.
PhysicsAnimationConfig
An AnimationConfig that simulates physical friction to decelerate the roulette wheel naturally.
Roulette
This is an animatable roulette widget. You need to present a RouletteController to control this widget.
RouletteController
Controller for Roulette widget.
RouletteGroup
Describe a total roulette
RouletteStyle
Describe the render style of roulette.
RouletteUnit
Describe a sector area of a Roulette
TappableRoulette
A tappable variant of Roulette.

Enums

SectionImageLayout
Determines how a background image is laid out within each roulette section.