RouletteUnit class
Describe a sector area of a Roulette
Constructors
-
RouletteUnit({String? text, TextStyle? textStyle, IconData? icon, ImageProvider<
Object> ? image, required Color color, required double weight}) -
const
- RouletteUnit.icon(IconData icon, {required Color color, double weight = 1.0, TextStyle style = RouletteStyle.defaultIconStyle})
-
Create a sector with an icon
const
-
RouletteUnit.image(ImageProvider<
Object> image, {Color color = const Color.fromRGBO(0, 0, 0, 0), double weight = 1.0, TextStyle style = RouletteStyle.defaultIconStyle}) -
Create a sector with an image
const
- RouletteUnit.noText({required Color color, double weight = 1.0})
-
Create a sector with only color but no text
const
- RouletteUnit.text(String text, {required Color color, TextStyle textStyle = RouletteStyle.defaultTextStyle, double weight = 1.0})
-
Create a sector with text
const
Properties
- color → Color
-
Backgroud color of the sector
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Icon of this sector
final
-
image
→ ImageProvider<
Object> ? -
Image of this sector
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text content of this sector
final
- textStyle → TextStyle?
-
Text style of this sector
final
- weight → double
-
Weight of this sector
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited