RouletteController class
Controller for Roulette widget.
Roulette widget use RouletteController to control the rotate animation and Roulette's display RouletteGroup.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetAnimation(
) → void - Reset animation to initial state
-
rollInfinitely(
{bool clockwise = true, Duration period = defaultPeriod, Curve? curve}) → Future< void> -
Start rolling the roulette indefinitely until a
rollTo, rollInfinitely or stop is called.
The
clockwisedetermine whether the animator should run in clockwise direction. Configperiodto update the roll period for one circle. If you want to change the cycle animation behavior, trycurve, but it may make the animation look wired. -
rollTo(
int targetIndex, {int minRotateCircles = defaultMinRotateCircles, bool clockwise = true, double offset = 0, AnimationConfig? animationConfig}) → Future< bool> -
Rolls the roulette to the item at
targetIndex. -
stop(
) → void - Stop current running animation. No animation will be performed, the roulette will stop at current position directly.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited